@@ -33,13 +33,14 @@ def main(target, ground, output, variables=None, mappings=None, authtype="pba"):
         target = make_lower(load_json(target))
         ground = make_lower(load_json(ground))
         v = None
-
+        is_csv = False
         if variables:
             if str(variables).endswith(".csv"):
+                is_csv = True
                 v = read_csv(variables)
             else:
+                is_csv = False
                 v = load_json(variables)
-
         version_map = {}
         path = f"src/scribe_updater/version_mapping/{mappings}"
         if os.path.isfile(path):
@@ -47,7 +48,7 @@ def main(target, ground, output, variables=None, mappings=None, authtype="pba"):
         else:
             version_map = {}
 
-        updater = Updater(ground, target, v, output, version_map)
+        updater = Updater(ground, target, v, output, version_map, is_csv)
 
         updater.prep_output_pba()
         updater.update()
